#!/bin/bash
#
# $Id: set_jtag_satellite.sh 20071 2014-01-28 08:28:45Z crt.valentincic $
#
# Set JTAG to ICB board
#
# Copyright (C) 2008 Instrumentation Technologies
#

PATH=$PATH:.:/opt/libera/bin
IPMITOOL="ipmitool -I bmc"

# Usage
function usage()
{
    echo "Usage: $0 board"
    echo "Script will set JTAG position to desired board."
    echo "   board:  ARM board number 0 .. 6"
    echo "   NOTE: Special case is ICB board, where board number is 0."
}

# Arguments sanity check
[ $# -ne 1 ] && {
    usage
    exit -1
}
[ $1 -lt 0 ] && {
    usage
    exit -1
}
[ $1 -gt 6 ] && {
    usage
    exit -1
}

function ipmi_tool()
{
  #echo ${IPMITOOL} $@
  RESVAL=`${IPMITOOL} $@ | grep -v "Opened USB device" | awk '{printf("0x%s%s", $3, $2)}'`
}

SATELLITE=$1
if [ $1 -eq 0 ] ; then
  # Power OFF Main+Management ARM on all slots
  for i in `seq 1 8` ; do 
    # echo Looping: $i ; 
    ipmi_tool raw 0 2 0 $i
    ipmi_tool raw 0 2 0 $i
  done

  # Switch JTAG_SEL_A to OFF
  ipmi_tool raw 0 2 0x19

  # Switch JTAG_SEL_L to OFF
  ipmi_tool raw 0 2 0x0C

  # Disable->Enable JTAG on ICB ARM
  ipmi_tool raw 0 2 0x18
  ipmi_tool raw 0 2 0x17

  # Set JTAG to default (slot #1)
  ipmi_tool raw 0 2 0xDC 0x20 0x00 0x00 0x00

else
  # Power OFF Main+Management on ARM
  ipmi_tool raw 0 2 0 ${SATELLITE}
  ipmi_tool raw 0 2 0 ${SATELLITE}

  # Switch JTAG to selected ARM
  ipmi_tool raw 0 2 0xDC 0x20 0x00 $((${SATELLITE}-1)) 0x00

  # Power ON Management power on ARM
  ipmi_tool raw 0 2 1 ${SATELLITE}

  # Switch JTAG_SEL_A to HIGH
  ipmi_tool raw 0 2 0x1A

  # Switch JTAG_SEL_L to HIGH
  ipmi_tool raw 0 2 0x0D

  # Trigger ENABLE (aka RESET) on ARM to attach to JTAG
  ipmi_tool raw 0 2 0xDC 0x1A 0x00 $((1<<(${SATELLITE}-1))) 0x00
  echo "Sleep for 20 seconds ..."
  sleep 20
  ipmi_tool raw 0 2 0xDC 0x1A 0x00 0x00 0x00

  # Set JTAG to ARM on sattelite #
  # Not needed. ipmi_tool raw 0 2 0x19 -t ${SATELLITE}
  
fi

#sudo openocd -f ./dbgtools/OOJT_lpc2378_configuration.cfg -f ./dbgtools/OOJT_lpc2378_commands.cmd -c "flash write_image ./icb1b/icb1b.bin 0x0 bin" -c "verify_image ./icb1b/icb1b.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f ./dbgtools/OOJT_lpc2146_configuration.cfg -f ./dbgtools/OOJT_lpc2146_commands.cmd -c "flash write_image ./vm1/vm1.bin 0x0 bin"" -c "verify_image ./vm1/vm1.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f ./dbgtools/OOJT_lpc2146_configuration.cfg -f ./dbgtools/OOJT_lpc2146_commands.cmd -c "flash write_image ./tcm1b/tcm1b.bin 0x0 bin"" -c "verify_image ./tcm1b/tcm1b.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f ./dbgtools/OOJT_lpc2146_configuration.cfg -f ./dbgtools/OOJT_lpc2146_commands.cmd -c "flash write_image ./adc9/adc9.bin 0x0 bin"" -c "verify_image ./adc9/adc9.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f ./dbgtools/OOJT_lpc2146_configuration.cfg -f ./dbgtools/OOJT_lpc2146_commands.cmd -c "flash write_image ./gdbrd/gdbrd.bin 0x0 bin"" -c "verify_image ./gdbrd/gdbrd.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"

#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2378_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2378_commands.cmd -c "flash write_image /opt/libera/fw/icb1b.bin 0x0 bin" -c "verify_image /opt/libera/fw/icb1b.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/vm1.bin 0x0 bin" -c "verify_image /opt/libera/fw/vm1.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/tcm1b.bin 0x0 bin" -c "verify_image /opt/libera/fw/t 0x0.bin bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/adc_llrf.bin 0x0 bin" -c "verify_image /opt/libera/fw/adc_llrf.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/adc_sph.bin 0x0 bin" -c "verify_image /opt/libera/fw/adc_sph.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/adc9.bin 0x0 bin" -c "verify_image /opt/libera/fw/adc9.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/gdbrd.bin 0x0 bin" -c "verify_image /opt/libera/fw/gdbrd.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/gdbrd_tim1.bin 0x0 bin" -c "verify_image /opt/libera/fw/gdbrd_tim1.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/gdbrd_evrx.bin 0x0 bin" -c "verify_image /opt/libera/fw/gdbrd_evrx.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
#sudo openocd -f /opt/libera/fw/scripts/OOJT_lpc2146_configuration.cfg -f /opt/libera/fw/scripts/OOJT_lpc2146_commands.cmd -c "flash write_image /opt/libera/fw/gdbrd_ser.bin 0x0 bin" -c "verify_image /opt/libera/fw/gdbrd_ser.bin 0x0 bin" -c "mdw 0x0 100" -c "reset run" -c "shutdown"
