#!/bin/bash
#
# $Id: spi2amba.sh 6779 2010-05-13 13:12:56Z primoz.beltram $
#
# read/write value to AMBA registers via SPI on ARM
#
# Copyright (C) 2008 Instrumentation Technologies
#

PATH=$PATH:.:/opt/libera/bin

SPI_AMBA_READ="ipmitool -I bmc raw 0 2 0xAB"
SPI_AMBA_WRITE="ipmitool -I bmc raw 0 2 0xAC"

# Operation success/failure return codes
SUCCESS=0

# SPI read/write return values.
RES=-1
RESVAL=-1

# Usage
function usage()
{
    echo "Usage: $0 target amba_register [value]"
    echo "   target:        ARM USB id (e.g. 103)"
    echo "   amba_register: 32-bit address to read (or write) in AMBA space (e.g. 0x32000)"
    echo "   value:         Optional, 32-bit value to write in AMBA register (e.g. 0x12345)"
}

# Arguments sanity check
[ $# -lt 2 ] && {
    usage
    exit -1
}
[ $# -gt 3 ] && {
    usage
    exit -1
}

function ipmi_amba_read()
{
  RESVAL=`${SPI_AMBA_READ} $(($1&0xFF)) $((($1>>8)&0xFF)) $((($1>>16)&0xFF)) $((($1>>24)&0xFF)) -t $2 | grep -v "Opened USB device" | awk '{printf("0x%s%s%s%s", $5, $4, $3, $2)}'`
}

function ipmi_amba_write()
{
  RES=`${SPI_AMBA_WRITE} $(($1&0xFF)) $((($1>>8)&0xFF)) $((($1>>16)&0xFF)) $((($1>>24)&0xFF)) $(($3&0xFF)) $((($3>>8)&0xFF)) $((($3>>16)&0xFF)) $((($3>>24)&0xFF)) -t $2`
}

TARGET=$1
AMBA_ADDR=$2
AMBA_VAL=$3

if [ $# -eq 3 ]; then #SPI2AMBA write

    ipmi_amba_write ${AMBA_ADDR} ${TARGET} ${AMBA_VAL}
    if [ $? -ne 0 ]; then
        SUCCESS=-1
    fi
    
else #SPI2AMBA read

    ipmi_amba_read ${AMBA_ADDR} ${TARGET}
    #Dump result.
    printf '0x%08x\n' ${RESVAL}
    
fi

exit ${SUCCESS}

